==> haskell-ghc-bignum-orphans-0.1.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-bignum-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-bignum-orphans
version:              0.1.1
visibility:           public
id:                   ghc-bignum-orphans-0.1.1-8veDOM99oe5CZzwLWHAoux
key:                  ghc-bignum-orphans-0.1.1-8veDOM99oe5CZzwLWHAoux
license:              BSD-3-Clause
copyright:            (C) 2021 Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ryan Scott
homepage:             https://github.com/haskell-compat/ghc-bignum-orphans
synopsis:             Backwards-compatible orphan instances for ghc-bignum
description:
    @ghc-bignum-orphans@ defines orphan instances that mimic
    instances available in later versions of @ghc-bignum@ to a
    wider (older) range of compilers. @ghc-bignum-orphans@ does
    not export anything except the orphan instances themselves.

category:             Compatibility
abi:                  c9eb714defd7f8651ee727e1d315fd47
exposed:              True
exposed-modules:      GHC.Num.Orphans
import-dirs:          /usr/lib/ghc-9.0.2/site-local/ghc-bignum-orphans-0.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/ghc-bignum-orphans-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/ghc-bignum-orphans-0.1.1
hs-libraries:         HSghc-bignum-orphans-0.1.1-8veDOM99oe5CZzwLWHAoux
depends:              base-4.15.1.0 ghc-bignum-1.1
haddock-interfaces:
    /usr/share/doc/haskell-ghc-bignum-orphans/html/ghc-bignum-orphans.haddock

haddock-html:         /usr/share/doc/haskell-ghc-bignum-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-bignum-orphans-0.1.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-bignum-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-bignum-orphans
version:              0.1.1
visibility:           public
id:                   ghc-bignum-orphans-0.1.1-E9ytHTuz5Ps3pEjpo5yLOY
key:                  ghc-bignum-orphans-0.1.1-E9ytHTuz5Ps3pEjpo5yLOY
license:              BSD-3-Clause
copyright:            (C) 2021 Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ryan Scott
homepage:             https://github.com/haskell-compat/ghc-bignum-orphans
synopsis:             Backwards-compatible orphan instances for ghc-bignum
description:
    @ghc-bignum-orphans@ defines orphan instances that mimic
    instances available in later versions of @ghc-bignum@ to a
    wider (older) range of compilers. @ghc-bignum-orphans@ does
    not export anything except the orphan instances themselves.

category:             Compatibility
abi:                  bbbe201d54f3d0a190657dbdc2075845
exposed:              True
exposed-modules:      GHC.Num.Orphans
import-dirs:          /usr/lib/ghc-9.2.8/site-local/ghc-bignum-orphans-0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ghc-bignum-orphans-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-bignum-orphans
hs-libraries:         HSghc-bignum-orphans-0.1.1-E9ytHTuz5Ps3pEjpo5yLOY
depends:              base-4.16.4.0 ghc-bignum-1.2
haddock-interfaces:
    /usr/share/doc/haskell-ghc-bignum-orphans/html/ghc-bignum-orphans.haddock

haddock-html:         /usr/share/doc/haskell-ghc-bignum-orphans/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
